@@ -19,7 +19,7 @@ class TestModelFancy with Gitalist::Git::CollectionOfRepositories {
         [$self->get_repository('repo1')]
     }
     method _get_repo_from_name($name) {
-        Gitalist::Git::Repository->new($self->repo_dir->subdir($name)->resolve);
+        Git::Gitalist::Repository->new($self->repo_dir->subdir($name)->resolve);
     }
 
     method debug_string { 'it is always repo1' }
